pub fn memory_stat() -> Result<MemoryStat, ReadParseError>Expand description
Reads and parses the memory statistics file.
Optional fields
- The memory statistics file MEMORY_STAT may not contain all fields. In this case, the field is assumed to be zero.
- In case the field’s value cannot be parsed to u64, the field is assumed to be zero (unlikely scenario).
Errors
Returns an error if the memory statistics file MEMORY_STAT could not be read or parsed.